<?php
 
/**
 * Plugin Name: LinePay
 * Description: Платёжная система LinePay для WooCommerce
 * Version: 1.0.1
 * Author: ktanster
 * Author URI: https://kwork.ru/user/ktanster
 */
 
if ( ! defined( 'WPINC' ) ) {
    die;
}

if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

define('WC_LINEPAY_PLUGIN_DIR_URL', plugin_dir_url(__FILE__));

/*
 * Check if WooCommerce is active
 */
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {	
	function wc_linepay_woocommerce_add_gateway($methods) {
		$methods[] = 'WC_LinePay';
		return $methods;
	}
	
	add_action('plugins_loaded', 'wc_linepay_woocommerce_gateway_init', 0);
	function wc_linepay_woocommerce_gateway_init() {
		if ( !class_exists( 'WC_Payment_Gateway' ) ) return;
		
		class WC_LinePay extends WC_Payment_Gateway {
			public $merchant_id;
			private $merchant_secret1;
			public $merchant_secret2;
			
			public function __construct() {
				$this->id = 'linepay';
				$this->icon = WC_LINEPAY_PLUGIN_DIR_URL.'favicon.png';
				$this->has_fields = true;
				$this->method_title = 'LinePay';
				$this->method_description = 'Платёжная система LinePay';
				$this->init_form_fields();
				$this->init_settings();
				add_action('woocommerce_update_options_payment_gateways_'.$this->id, array($this, 'process_admin_options'));
			}
			
			public function init_form_fields() {
				$this->form_fields = array(
					'enabled' => array(
						'title' => __( 'Enable/Disable', 'woocommerce' ),
						'type' => 'checkbox',
						'label' => __( 'Enabled', 'woocommerce' ),
						'default' => 'yes'
					),
					'title' => array(
						'title' => __( 'Title', 'woocommerce' ),
						'type' => 'text',
						'description' => __( 'This controls the title which the user sees during checkout.', 'woocommerce' ),
						'default' => 'LinePay',
						'desc_tip'      => true,
					),
					'description' => array(
						'title' => 'Описание',
						'type' => 'textarea',
						'default' => ''
					),
					'hf1' => array(
						'title' => 'URL оповещения',
						'type' => 'hidden',
						'default' => '',
						'description' => WC_LINEPAY_PLUGIN_DIR_URL.'notify.php',
					),
					'hf2' => array(
						'title' => 'URL успешной оплаты',
						'type' => 'hidden',
						'default' => '',
						'description' => WC_LINEPAY_PLUGIN_DIR_URL.'success.php',
					),
					'hf3' => array(
						'title' => 'URL неуспешной оплаты',
						'type' => 'hidden',
						'default' => '',
						'description' => WC_LINEPAY_PLUGIN_DIR_URL.'failed.php',
					),
					'merchant_id' => array(
						'title' => 'ID магазина',
						'type' => 'text',
						'default' => ''
					),
					'merchant_secret1' => array(
						'title' => 'Секретное слово 1',
						'type' => 'password',
						'default' => ''
					),
					'merchant_secret2' => array(
						'title' => 'Секретное слово 2',
						'type' => 'password',
						'default' => ''
					)
				);
				$this->title = $this->get_option( 'title' );
				$this->description = $this->get_option( 'description' );
				$this->merchant_id = $this->get_option('merchant_id');
				$this->merchant_secret1 = $this->get_option('merchant_secret1');
				$this->merchant_secret2 = $this->get_option('merchant_secret2');
			}
			
			public function process_payment( $order_id ) {
				global $woocommerce;
				$order = new WC_Order( $order_id );

				$order->update_status('pending');

				$woocommerce->cart->empty_cart();
				$m_id = $this->merchant_id;
				$m_secret_1 = $this->merchant_secret1;
				$amount = $order->get_total();
				update_post_meta($order_id, 'wc_linepay_amount', $amount);
				$sign = md5($m_id.'|'.$m_secret_1.'|'.$amount.'|'.$order_id);
				$_SESSION['wc_linepay_order_id'] = $order_id;
				return array(
					'result' => 'success',
					'redirect' => 'https://linepay.fun/pay?order_id='.urlencode($order_id).'&m_id='.urlencode($m_id).'&amount='.urlencode($amount).'&sign='.urlencode($sign),
				);
			}
		}
		
		add_filter('woocommerce_payment_gateways', 'wc_linepay_woocommerce_add_gateway' );
	}
}
